Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
Functions ¶
Types ¶
type Interface ¶
type Interface interface {
Start() error
Stop() error
KeyExists(resource string, namespace string, key string) (bool, error)
KeyList(resource string, namespace string) []string
AttrList(resource string, namespace string, key string) []string
AttrExists(resource string, namespace string, attr string, key string) (bool, error)
BlobExists(resource string, namespace string, attr string, key string) (bool, error)
AttrSet(resource string, namespace string, attr string, key string, value []byte, replace bool) error
AttrGet(resource string, namespace string, attr string, key string) ([]byte, error)
BlobWrite(resource string, namespace string, attr string, key string, data io.ReadCloser, replace bool) error
BlobRead(resource string, namespace string, attr string, key string) (io.ReadCloser, error)
AttrDelete(resource string, namespace string, attr string, key string) error
AttrWatch(resource string, namespace string, attr string, callback WatchCallbackFunc) (WatchStopFunc, error)
}
type Options ¶ added in v0.1.1
type Options struct {
// contains filtered or unexported fields
}
type WatchCallbackFunc ¶
type WriteData ¶
type WriteData struct {
}
Source Files
¶
- error.go
- event.go
- impl.go
- main.go
- options.go
Click to show internal directories.
Click to hide internal directories.